.. _using-index:

############
Installation
############


This part of the documentation is devoted to general information on the setup
and configuration of SAGA and things that make working with SAGA easier.


.. toctree::
   :numbered:

   install.rst
   redis.rst
   trouble.rst
